/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIESREGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2015 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************
* File Name    : r_intadc.c
* Device(s)    : R5F10267
* Tool-Chain   : CC-RL
* Description  : This file implements device driver for ADC module.
* Creation Date: 2015/11/18
************************************************************************/

/***********************************************************************
Includes
************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_userdefine.h"

/***********************************************************************
Pragma directive
************************************************************************/
#pragma interrupt INTAD r_adc_interrupt

/***********************************************************************
Global variables and functions
************************************************************************/
#define     CH_NO           (2)             /* A/D input channel number     */
uint16_t static g_conv_data[SAMPLE][CH_NO]; /* A/D conversion data          */
uint16_t sum_data[CH_NO];                   /* accumulate of channel        */
uint8_t sreg Adc_End;                       /* A/D conversion end flag      */
uint16_t static sreg *gp_set_pt;            /* convert data set pointer     */
uint16_t static sreg *gp_sum_pt;            /* accumelate data pointer      */

void R_ADC_Init(void);                      /* initialize ADC parameters    */

/***********************************************************************
* Function Name: R_ADC_Init
* Description  : This function initialize A/D data.
* Arguments    : None
* Return Value : None
************************************************************************/
void R_ADC_Init(void)
{
        uint8_t i;

/* clear accumulate data area   */

    for ( i=0 ; i < CH_NO ; i++ )
    {
        sum_data[i] = 0;                 /* clear accumulate data    */
    }

/* clear measured data of A/D converter */

    for ( gp_set_pt = &g_conv_data[0][0] ; gp_set_pt <= &g_conv_data[SAMPLE-1][CH_NO-1] ; gp_set_pt++ )
    {
        *gp_set_pt = 0;                 /* clear measured data      */
    }

/* initailize parameters for A/D conversion data buffer */

    gp_set_pt = &g_conv_data[0][0];     /* initialize set pointer   */
    gp_sum_pt = &sum_data[0];           /* initialize sum pointer   */
    Adc_End = FALSE;

}/* End of function R_ADC_Init() */

/***********************************************************************
* Function Name: r_adc_interrupt
* Description  : This function is INTAD interrupt service routine.
* Arguments    : None
* Return Value : None
************************************************************************/
__interrupt static void r_adc_interrupt(void)
{
    uint16_t data_work;

    data_work = ADCRL >> 6;             /* get new convert data     */
    data_work |= (ADCRH << 2);          /* add high byte data       */
    ADS ^= 0b00000111;                  /* change A/C channel       */
    ADCS = TRUTH;                       /* start AD conversion      */
    *gp_sum_pt -= *gp_set_pt;           /* sub old data from sum    */
    *gp_set_pt = data_work;             /* set new data             */
    *gp_sum_pt += data_work;            /* accumulate new data      */

    gp_sum_pt++;                        /* go next channel          */
    gp_set_pt++;

    if  ( gp_sum_pt >  &sum_data[CH_NO-1] ) /* check all end or not   */
    {

/*--------------------------------------
    end accunulate all channel data
    (move gp_sum_pter to the top)
--------------------------------------*/

        gp_sum_pt = &sum_data[0];
        if ( gp_set_pt > &g_conv_data[SAMPLE-1][CH_NO-1]) /* buffer end check */
        {

/*--------------------------------------
    store all converted data in buffer
    (move pointer to the top)
--------------------------------------*/

            gp_set_pt = &g_conv_data[0][0];

        }
        else
        {
            /* do nothing */
        }

        Adc_End = TRUTH;                /* set data ready flag          */

    }
    else
    {
        /* do nothing */
    }

}/* End of interrupt function r_adc_interrupt() */

/***********************************************************************
* Function Name: R_ADC_Start
* Description  : This function starts the AD converter.
* Arguments    : None
* Return Value : None
************************************************************************/
void R_ADC_Start(void)
{
    ADIF = FALSE;                       /* clear INTAD interrupt flag   */
    ADMK = INT_ENABLE;                  /* enable INTAD interrupt       */
    ADCS = TRUTH;                       /* start AD conversion          */

}/* End of function R_ADC_Start() */

