/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIESREGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2011, 2015 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************
* File Name    : r_inttm.c
* Device(s)    : R5F10267
* Tool-Chain   : CC-RL
* Description  : This file implements device driver for TAU module.
* Creation Date: 2015/11/09
************************************************************************/

/***********************************************************************
Includes
************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_userdefine.h"
#include "r_intadc.h"

/***********************************************************************
Pragma directive
************************************************************************/
#pragma interrupt INTTM00 r_tau0_channel0_interrupt

/***********************************************************************
Global variables and functions
************************************************************************/
#define     DISP_OFF_DATA   (0b00001111)    /* display off data for P0      */
#define     TIMING1         (0b00001111)    /* display timing1 data for P0  */
#define     TIMING2         (0b00000000)    /* display timing2 data for P0  */
#define     KEY_TIMING      (10)            /* key check every 50ms         */
#define     DATA_MASK       (DATA_NUMBER-1) /* mask data for pointer        */

uint8_t static g_disp_data_bf[DATA_NUMBER]; /* display data buffer area     */
uint8_t static g_sel_data;                  /* display data select          */

uint8_t static sreg g_disp_timing;          /* display data timing          */

void R_Make_DISP_data(uint8_t CH_No, uint8_t in_data);
                                            /* convert data to LED data     */
void R_DISP_Init(void);                     /* initialize dislay parameters */

/*******************************************************************
* Function Name: R_DISP_Init
* Description  : This function initialize display data image
* Arguments    : None
* Return Value : None
********************************************************************/
void R_DISP_Init(void)
{
    uint8_t i;

    for ( i = 0 ; i < DATA_NUMBER ; i++ )
    {
        g_disp_data_bf[i] = 0x00;           /* clear display buffer         */
    }

    g_sel_data = 0x00;                      /* select display data0         */
    g_disp_timing = 0x00;                   /* initialize display timing    */

}/* End of function R_DISP_Init() */

/*******************************************************************
* Function Name: R_Make_DISP_data
* Description  : This function set display data in buffer
* Arguments    : CH_No,in_data
* Return Value : None(g_disp_data)
********************************************************************/
void R_Make_DISP_data(uint8_t CH_No,uint8_t in_data)
{

    g_disp_data_bf[(DATA_MASK & CH_No)] = in_data;

}/* End of function R_Make_DISP_data() */

/***********************************************************************
* Function Name: r_tau0_channel0_interrupt
* Description  : This function is INTTM00 interrupt service routine.
* Arguments    : None
* Return Value : None
************************************************************************/
__interrupt static void r_tau0_channel0_interrupt(void)
{

    uint8_t disp_work;

    PM0 |= DISP_OFF_DATA;                   /* clear display            */

    disp_work = g_disp_data_bf[g_sel_data]; /* get display data         */

    if ( FALSE == ( g_disp_timing & 0x01 ) )
    {                                       /* display timing 1         */
        disp_work = disp_work >> 4;         /* disp high nibble data    */
        P0 = TIMING1;                       /* set P03-00 high level    */
        P4.1 = 0;                           /* drive P41 to low         */
    }
    else
    {                                       /* display timing 2         */
        disp_work &= DISP_OFF_DATA;         /* set low nibble of data   */
        P0 = TIMING2;                       /* set P03-00 low level     */
        P4.1 = 1;                           /* drive P41 to high        */
    }

    PM0 ^= disp_work;                       /* set on bit to output     */
/*
    display timing cout up
*/
    g_disp_timing++;                        /* count up timing counter  */

    if ( KEY_TIMING <= g_disp_timing )      /* check key check timing   */
    {
        g_disp_timing = 0x00;               /* initialize display timing*/

        if ( FALSE == P13.7 )
        {                                   /* key switch is pushed     */
            g_sel_data = 0x01;              /* select display data2     */
        }
        else
        {                                   /* key switch is not pushed */
            g_sel_data = 0x00;              /* select display data1 */
        }
    }
    else
    {
        /* do nothing */
    }

}/* End of interrupt function r_tau0_channel0_interrupt() */

/***********************************************************************
* Function Name: R_TAU0_Channel0_Start
* Description  : This function starts TAU0 channel 0 counter.
* Arguments    : None
* Return Value : None
************************************************************************/
void R_TAU0_Channel0_Start(void)
{
    TMIF00 = FALSE;                     /* clear INTTM00 interrupt flag */
    TMMK00 = INT_ENABLE;                /* enable INTTM00 interrupt */
    TS0 |= 0x01;                        /* start TM00 operation     */

}/* End of function R_TAU0_Channel0_Start() */
